==> checkstyle_5.9.orig.tar.gz: checkstyle-5.9/src/main/java/com/puppycrawl/tools/checkstyle/checks/blocks/BlockOption.java <==
////////////////////////////////////////////////////////////////////////////////
// checkstyle: Checks Java source code for adherence to a set of rules.
// Copyright (C) 2001-2014  Oliver Burn
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////////
package com.puppycrawl.tools.checkstyle.checks.blocks;

/**
 * Represents the policy for checking block statements.
 * @see com.puppycrawl.tools.checkstyle.checks.blocks.EmptyBlockCheck
 * @author Rick Giles
 */
public enum BlockOption
{
    /**
     * Represents the policy that there is some text in the block. For example:
     *
     * <pre>
     * catch (Exception ex) {
     *     // This is a bad coding practice
     * }
     * </pre>
     */
    TEXT,

    /**
     * Represents the policy that there is a statement in the block. For
     * example:
     *
     * <pre>
     * finally {
     *     lock.release();
     * }
     * </pre>
     */
    STMT;
}

==> checkstyle_6.13.orig.tar.gz: checkstyle-6.13/src/main/java/com/puppycrawl/tools/checkstyle/checks/blocks/BlockOption.java <==
////////////////////////////////////////////////////////////////////////////////
// checkstyle: Checks Java source code for adherence to a set of rules.
// Copyright (C) 2001-2015 the original author or authors.
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////////

package com.puppycrawl.tools.checkstyle.checks.blocks;

/**
 * Represents the policy for checking block statements.
 * @author Rick Giles
 * @see EmptyBlockCheck
 */
public enum BlockOption {
    /**
     * Represents the policy that there is some text in the block. For example:
     *
     * <pre>
     * catch (Exception ex) {
     *     // This is a bad coding practice
     * }
     * </pre>
     */
    TEXT,

    /**
     * Represents the policy that there is a statement in the block. For
     * example:
     *
     * <pre>
     * finally {
     *     lock.release();
     * }
     * </pre>
     */
    STMT
}
